@@ -2,6 +2,7 @@ import datetime
 import os
 import sys
 import time
+from typing import Any
 
 from . import (getAllFileList, getFileBaseName, getPath, hold, makeFolder,
                readFile, remove, writeFile)
@@ -12,10 +13,10 @@ from .print import (BACKGROUND_DARKGREEN, BACKGROUND_DARKPINK,
                     FOREGROUND_BLACK, FOREGROUND_DARKRED, FOREGROUND_WHITE,
                     resetPrintColor, setPrintColor)
 
-_workspacePath = None
+_workspacePath: str = ""
 
 
-def initTask(exeWorkspace, devWorkspace, devTaskList):
+def initTask(exeWorkspace: str, devWorkspace: str, devTaskList: list[list[Any]]):
     global _workspacePath
     if _isDev():
         _workspacePath = getPath(devWorkspace)
@@ -25,11 +26,11 @@ def initTask(exeWorkspace, devWorkspace, devTaskList):
         _runTaskFile(sys.argv[-1])
 
 
-def getPathByWorkspace(*parList) -> str:
+def getPathByWorkspace(*parList: str) -> str:
     return getPath(_workspacePath, *parList)
 
 
-def runTask(moduleName, **parDict):
+def runTask(moduleName: str, **parDict: dict[str, Any]):
     exec(f"import {moduleName}")
     module = eval(moduleName)
     for k, v in parDict.items():
@@ -62,8 +63,9 @@ def _setPrintRedColor():
     setPrintColor(FOREGROUND_DARKRED)
 
 
-def _runTaskFile(file):
+def _runTaskFile(file: str):
     isException = False
+    taskList: list[list[Any]] = []
     try:
         fileContent = readFile(file)
         findStr = ":: ---------------------------------------- ::"
@@ -72,7 +74,6 @@ def _runTaskFile(file):
         content = fileContent[startIndex + len(findStr):endIndex].strip().replace("\r\n", "\n")
         lineAry = content.split("\n")
         lineAry = [x[2:].strip() for x in lineAry]
-        taskList = []
         for line in lineAry:
             sepIndex = line.find(" ")
             if sepIndex > -1:
@@ -98,7 +99,7 @@ def _runTaskFile(file):
 
 
 # [[moduleName, parDict], ...]
-def _runTaskList(taskList):
+def _runTaskList(taskList: list[list[Any]]):
     startTime = datetime.datetime.now()
     lockFile = None
     try:
@@ -110,7 +111,7 @@ def _runTaskList(taskList):
         logFile = getPath(logFolder, f"{time.strftime('%Y%m%d_%H%M%S')}.log")
         initLogger(logFile=logFile)
         for moduleName, *parList in taskList:
-            parDict = parList and parList[0] or {}
+            parDict: Any = parList and parList[0] or {}
             runTask(moduleName, **parDict)
     except Exception:
         import traceback
